@@ -51,6 +51,7 @@
 #include "macvlandevice.h"
 #include "tundevice.h"
 #include "vethdevice.h"
+#include "wireguarddevice.h"
 
 #include "nmdebug.h"
 
@@ -165,7 +166,8 @@ void NetworkManager::NetworkManagerPrivate::init()
                NetworkManager::Device::MacVlan |
                NetworkManager::Device::Tun |
                NetworkManager::Device::Veth |
-               NetworkManager::Device::IpTunnel
+               NetworkManager::Device::IpTunnel |
+               NetworkManager::Device::WireGuard
            );
 
     // Get all Manager's properties async
@@ -364,6 +366,9 @@ NetworkManager::Device::Ptr NetworkManager::NetworkManagerPrivate::createNetwork
     case Device::IpTunnel:
         createdInterface = Device::Ptr(new NetworkManager::IpTunnelDevice(uni), &QObject::deleteLater);
         break;
+    case Device::WireGuard:
+        createdInterface = Device::Ptr(new NetworkManager::WireGuardDevice(uni), &QObject::deleteLater);
+        break;
     default:
         createdInterface = device;
         if (uni != QLatin1String("any")) { // VPN connections use "any" as uni for the network interface.
@@ -638,7 +643,7 @@ void NetworkManager::NetworkManagerPrivate::setLogging(NetworkManager::LogLevel
             logDomains << QLatin1String("DISPATCH");
         }
     }
-    iface.SetLogging(logLevel, logDomains.join(QLatin1String(",")));
+    iface.SetLogging(logLevel, logDomains.join(QLatin1Char(',')));
 }
 
 NMStringMap NetworkManager::NetworkManagerPrivate::permissions()
